pub struct TransferData {
pub name: String,
pub transfer_status: String,
pub requester_id: String,
pub requested_at: DateTime<Utc>,
pub ack_id: String,
pub ack_by: DateTime<Utc>,
pub expiring_at: Option<DateTime<Utc>>,
}Expand description
Type that represents the <trnData> tag for domain transfer response
Fields
name: StringThe domain name
transfer_status: StringThe domain transfer status
requester_id: StringThe epp user who requested the transfer
requested_at: DateTime<Utc>The transfer rquest date
ack_id: StringThe epp user who should acknowledge the transfer request
ack_by: DateTime<Utc>THe date by which the acknowledgment should be made
expiring_at: Option<DateTime<Utc>>The domain expiry date